==> symbol-processing-aa-embeddable-2.3.0-sources.jar: org/jetbrains/kotlin/psi/stubs/elements/KtFileElementType.kt <==
/*
 * Copyright 2010-2025 JetBrains s.r.o. and Kotlin Programming Language contributors.
 * Use of this source code is governed by the Apache 2.0 license that can be found in the license/LICENSE.txt file.
 */
package ksp.org.jetbrains.kotlin.psi.stubs.elements

import ksp.com.intellij.lang.ASTNode
import ksp.com.intellij.lang.PsiBuilderFactory
import ksp.com.intellij.psi.PsiElement
import ksp.com.intellij.psi.StubBuilder
import ksp.com.intellij.psi.stubs.*
import ksp.com.intellij.psi.tree.IStubFileElementType
import ksp.org.jetbrains.kotlin.idea.KotlinLanguage
import ksp.org.jetbrains.kotlin.parsing.KotlinParser
import ksp.org.jetbrains.kotlin.psi.KtImplementationDetail
import ksp.org.jetbrains.kotlin.psi.stubs.KotlinStubVersions
import ksp.org.jetbrains.kotlin.psi.stubs.impl.KotlinFileStubImpl
import ksp.org.jetbrains.kotlin.psi.stubs.impl.KotlinFileStubKindImpl

@OptIn(KtImplementationDetail::class)
object KtFileElementType : IStubFileElementType<KotlinFileStubImpl>(KtFileElementType.NAME, KotlinLanguage.INSTANCE) {
    internal const val NAME = "kotlin.FILE"

    override fun getBuilder(): StubBuilder {
        return KtFileStubBuilder()
    }

    override fun getStubVersion(): Int {
        return KotlinStubVersions.SOURCE_STUB_VERSION
    }

    override fun getExternalId(): String {
        return NAME
    }

    override fun serialize(stub: KotlinFileStubImpl, dataStream: StubOutputStream) {
        KotlinFileStubKindImpl.serialize(stub.kind, dataStream)
    }

    override fun deserialize(dataStream: StubInputStream, parentStub: StubElement<*>?): KotlinFileStubImpl {
        val kind = KotlinFileStubKindImpl.deserialize(dataStream)
        return KotlinFileStubImpl(file = null, kind = kind)
    }

    override fun doParseContents(chameleon: ASTNode, psi: PsiElement): ASTNode? {
        val project = psi.project
        val languageForParser = getLanguageForParser(psi)
        val builder = PsiBuilderFactory.getInstance().createBuilder(project, chameleon, null, languageForParser, chameleon.chars)
        return KotlinParser.parse(builder, psi.containingFile).firstChildNode
    }

    override fun indexStub(stub: PsiFileStub<*>, sink: IndexSink) {
        StubIndexService.getInstance().indexFile(stub as KotlinFileStubImpl, sink)
    }
}

==> symbol-processing-aa-embeddable-2.3.3-sources.jar: org/jetbrains/kotlin/psi/stubs/elements/KtFileElementType.kt <==
/*
 * Copyright 2010-2025 JetBrains s.r.o. and Kotlin Programming Language contributors.
 * Use of this source code is governed by the Apache 2.0 license that can be found in the license/LICENSE.txt file.
 */
package ksp.org.jetbrains.kotlin.psi.stubs.elements

import ksp.com.intellij.lang.ASTNode
import ksp.com.intellij.lang.PsiBuilderFactory
import ksp.com.intellij.psi.PsiElement
import ksp.com.intellij.psi.StubBuilder
import ksp.com.intellij.psi.stubs.*
import ksp.com.intellij.psi.tree.IStubFileElementType
import ksp.org.jetbrains.kotlin.idea.KotlinLanguage
import ksp.org.jetbrains.kotlin.parsing.KotlinParser
import ksp.org.jetbrains.kotlin.psi.KtImplementationDetail
import ksp.org.jetbrains.kotlin.psi.stubs.KotlinStubVersions
import ksp.org.jetbrains.kotlin.psi.stubs.impl.KotlinFileStubImpl
import ksp.org.jetbrains.kotlin.psi.stubs.impl.KotlinFileStubKindImpl

@OptIn(KtImplementationDetail::class)
object KtFileElementType : IStubFileElementType<KotlinFileStubImpl>(KtFileElementType.NAME, KotlinLanguage.INSTANCE) {
    internal const val NAME = "kotlin.FILE"

    override fun getBuilder(): StubBuilder {
        return KtFileStubBuilder()
    }

    override fun getStubVersion(): Int {
        return KotlinStubVersions.SOURCE_STUB_VERSION
    }

    override fun getExternalId(): String {
        return NAME
    }

    override fun serialize(stub: KotlinFileStubImpl, dataStream: StubOutputStream) {
        KotlinFileStubKindImpl.serialize(stub.kind, dataStream)
    }

    override fun deserialize(dataStream: StubInputStream, parentStub: StubElement<*>?): KotlinFileStubImpl {
        val kind = KotlinFileStubKindImpl.deserialize(dataStream)
        return KotlinFileStubImpl(ktFile = null, kind = kind)
    }

    override fun doParseContents(chameleon: ASTNode, psi: PsiElement): ASTNode? {
        val project = psi.project
        val languageForParser = getLanguageForParser(psi)
        val builder = PsiBuilderFactory.getInstance().createBuilder(project, chameleon, null, languageForParser, chameleon.chars)
        return KotlinParser.parse(builder, psi.containingFile).firstChildNode
    }

    override fun indexStub(stub: PsiFileStub<*>, sink: IndexSink) {
        StubIndexService.getInstance().indexFile(stub as KotlinFileStubImpl, sink)
    }
}
